==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementNotStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class WebAclRuleStatementNotStatementArgs(
    public val statements: Output<List<WebAclRuleStatementArgs>>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementNotStatementArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementNotStatementArgsBuilder internal constructor() {
    private var statements: Output<List<WebAclRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("pxtruepwfasacbro")
    public suspend fun statements(`value`: Output<List<WebAclRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("jxbxpcukujerdnpl")
    public suspend fun statements(vararg values: Output<WebAclRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("pxgmslxldfltnguw")
    public suspend fun statements(values: List<Output<WebAclRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("hrcuhywbswqjuabx")
    public suspend fun statements(`value`: List<WebAclRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("qhptgiruacqjrwoo")
    public suspend fun statements(argument: List<suspend WebAclRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("xepfpidnpsotsomv")
    public suspend fun statements(
        vararg
        argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("xkybbbifsllgkjmt")
    public suspend fun statements(argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebAclRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("rudmttllfqobepnp")
    public suspend fun statements(vararg values: WebAclRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): WebAclRuleStatementNotStatementArgs = WebAclRuleStatementNotStatementArgs(
        statements = statements ?: throw PulumiNullFieldException("statements"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclRuleStatementNotStatementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property statements The statements to combine.
 */
public data class WebAclRuleStatementNotStatementArgs(
    public val statements: Output<List<WebAclRuleStatementArgs>>,
) : ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs =
        com.pulumi.aws.wafv2.inputs.WebAclRuleStatementNotStatementArgs.builder()
            .statements(
                statements.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebAclRuleStatementNotStatementArgs].
 */
@PulumiTagMarker
public class WebAclRuleStatementNotStatementArgsBuilder internal constructor() {
    private var statements: Output<List<WebAclRuleStatementArgs>>? = null

    /**
     * @param value The statements to combine.
     */
    @JvmName("awsgpknaxweyhwnm")
    public suspend fun statements(`value`: Output<List<WebAclRuleStatementArgs>>) {
        this.statements = value
    }

    @JvmName("ntbmmuokjftgydyn")
    public suspend fun statements(vararg values: Output<WebAclRuleStatementArgs>) {
        this.statements = Output.all(values.asList())
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("dupwdjmswvndrfps")
    public suspend fun statements(values: List<Output<WebAclRuleStatementArgs>>) {
        this.statements = Output.all(values)
    }

    /**
     * @param value The statements to combine.
     */
    @JvmName("jxhjlybnmptlkstk")
    public suspend fun statements(`value`: List<WebAclRuleStatementArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("misbikmmnemccuew")
    public suspend fun statements(argument: List<suspend WebAclRuleStatementArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("edwvejmsmxdoufwu")
    public suspend fun statements(vararg argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            WebAclRuleStatementArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param argument The statements to combine.
     */
    @JvmName("xgtpxwhyyoxkstsw")
    public suspend fun statements(argument: suspend WebAclRuleStatementArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebAclRuleStatementArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.statements = mapped
    }

    /**
     * @param values The statements to combine.
     */
    @JvmName("cyounmtrbfyhbnrg")
    public suspend fun statements(vararg values: WebAclRuleStatementArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.statements = mapped
    }

    internal fun build(): WebAclRuleStatementNotStatementArgs = WebAclRuleStatementNotStatementArgs(
        statements = statements ?: throw PulumiNullFieldException("statements"),
    )
}
